@@ -1,11 +1,10 @@
 from django.db.models import ForeignKey
 
 
-def object_to_dict(obj, blacklisted_fields=None, include_id=False):
+def object_to_dict(obj, blacklisted_fields: list = None, include_id: bool = False) -> dict:
     """
     Returns a dict with all data defined in the model class as a key-value-dict
     Attention: Does not work for M2M fields!
-    :return:
     """
 
     # Default blacklist
