@@ -1,9 +1,23 @@
+from django.contrib.auth.models import User
 from django.test import TestCase
 from django.views.generic import View
 from django.views.generic.detail import SingleObjectMixin
 
 from ai_django_core.tests.mixins import RequestProviderMixin
 from ai_django_core.view_layer.views import ToggleView
+from testapp.views import UserInFormKwargsMixinView
+
+
+class UserInFormKwargsMixinTest(RequestProviderMixin, TestCase):
+    def test_get_form_kwargs_regular(self):
+        user = User(username='my-user')
+
+        view = UserInFormKwargsMixinView()
+        view.request = self.get_request(user=user)
+        form_kwargs = view.get_form_kwargs()
+
+        self.assertIn('user', form_kwargs)
+        self.assertEqual(form_kwargs['user'], user)
 
 
 class ToggleViewTest(RequestProviderMixin, TestCase):
